@@ -73,20 +73,6 @@ class TestSequentialBuilder(TestCase):
         self.assertSequenceEqual(model.output_shape, (None, 3))
         self.assertEqual(model.count_params(), 11321)
 
-    def test_medgeconv(self):
-        toml_file = "graph_medgeconv.toml"
-
-        model_file = os.path.join(self.example_dir, toml_file)
-        mb = orcanet.model_builder.ModelBuilder(model_file)
-        orga = self.get_orga(dims="graph")
-        orga.cfg.batchsize = 64
-        orga.cfg.fixed_batchsize = True
-        model = mb.build(orga)
-
-        self.assertSequenceEqual(model.output_shape, (64, 3))
-        self.assertEqual(model.count_params(), 304223)
-        self.assertEqual(len(model.layers), 87)
-
     def test_disjoint_edgeconv(self):
         toml_file = "graph_disjoint_edgeconv.toml"
 
